@@ -1,6 +1,7 @@
 
 
-
+skip_on_cran()
+skip_on_ci()
 
 test_that("population_plot() works", {
   
